# Requirements and Competency Questions 


1. **Which domain should be covered by the ontology?** 

	- Simulation of a whole steel production workflow from rolling till crashtest with all intermediate testing

	- Building a digital twin

2. **What should the ontology be used for?** 

	- Semantic storage for relations between material properties and processing steps as also semantic storage for the simulation workflow. The ontology should be used to discover unserspecified process and reasons for given results.

3. **Who will use the ontology?**

	- Domain experts. Manufacturers, Engineers and Scientist closely related to steel production and processing.

4. **What questions should be answered by the ontology?** (max 15 questions) 

### CQ1 – Which properties do all [materials/steels] have in common that took part in each set of [crash tests/filter]? 

**Vote**: [Not rated] 

**Necessity**: Desired 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. A couple of crash tests show some abnormal deformation. This abnormality might be rooted in the construction of the frame or the material itself. For further analysis, all properties of the steels taking part in the abnormal crash tests should be returned. CQ1.1 and CQ1.2 are a follow up questions. 

List all properties (e.g., tensile strength, stress-strain curves for different strain rates, fracture strain, coating, color) 

**Remarks**: 


#### CQ1.1 - Which are the common properties of all [materials/steels] from a given subset of [crash tests/stress tests] and only those properties with a logical connection to the (tests, deformation)? 

**Vote**: [Not rated] 

**Necessity**: Desired 

**Belonging**: [Not specified] 

**Description**: 

Extended version of CQ1. 

The given question tries to cover the following scenario. Instead of comparing a diff of properties like in CQ1.2 questions CQ1.1 requires some deduction of relevant properties regarding a test. 

**Remarks**: 

Logical connection to some outcome is unclear, how to model something like this? 


#### CQ1.2 List all properties of structural relevance for the [materials/steels] that differ from two sets of [materials/steels] 

**Vote**: [Not rated] 

**Necessity**: [Not evaluated] 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. Two CQ1 queries have been performed for abnormal and normal crash tests each list of [materials/steels] should now be compared to spot an abnormality. Although [materials/steels] can have a multitude of properties only those of structural relevance should be returned. Properties like color should be neglected. 

**Remarks**: 

Properties must be classified as structural important by domain experts 



### CQ2 - Which [grain sizes OR carbon proportion] were present in the tensile tests that reached at least a total elongation (strain might be a better term) of [x]? 

**Vote**: [Not rated] 

**Necessity**: Desired, but with remarks

**Belonging**: Material Science Specific 

**Description**: 

The given question tries to cover the following scenario. Some tensile tests show interesting results. The source of those results is unknown but a comparison of grain sizes or carbon proportion might be the cause. The expected result should be a list of all grain sizes of the materials that reached a given total elongation. The elongation might be measured with different units. 

**Remarks**: 

Relating Grain-size to total elongation not a good question, better use a first length. The total elongation varies with the size of the specimen. A better measure would be to use a relative measure in respect to initial elongation and total elongation (Strain) 

The term elongation is ambiguously used in literature. A further discussion on ambiguous terms from the steel domain is required 

The reason for a result is most import. Is the grain size physically connected to the elongation?
 

### CQ3 - How many parameters must be calculated to solve \Tac_c for \alpha given a Taylor series?

**Vote**: [Not rated]

**Necessity**: [Not evaluated]

**Belonging**: [Not specified] 

**Description**:

**Remarks**:
Dirks help is required


#### CQ3.1 How many training sets and descriptors do I need get a reasonable desc. of my model? 

**Vote**: [Not rated] 

**Necessity**: [Not evaluated]

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 


#### CQ3.2 How many datapoints do I need to calculate a yield surface with a given precision? 

**Vote**: [Not rated] 

**Necessity**: Required 

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 

wanted for intelligent material card 

regression must be performed on the I/O parameters 


#### CQ3.3 How many parameters do I need to have a completeness of my parameter set with respect to a certain mathematical evaluation? 

**Vote**: [Not rated] 

**Necessity**: [Not evaluated] 

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 


### CQ4 - Which steels with known [grain sizes] have the same properties as the given steel [X] with an unknown [grain size, property]? 

**Vote**: [Not rated] 

**Necessity**: [Not evaluated] 

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 

#### CQ4.1 - What is the property at a given point on a material based on some other known(measured) points? 

**Vote**: [Not rated] 

**Necessity**: [not evaluated] 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. A component with non-uniform thinness is tested multiple times and the grain size on those untested areas should be interpolated / derived. Additionally, the mechanical performance of that material in should be derived.  

**Remarks**: 


### CQ5 - {who OR which machine} performed a given set of Tensile tests with results in a range between [a] and [b]? 

**Vote**: [Not rated]

**Necessity**: [Required, Desired, Rejected] 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. The cause for unexpected results does not need to be an internal reason, but external. For example, a machine, the operator or the testing procedure. Including and comparing external factors might help to determine the cause. 

**Remarks**: 

For credit reasons this question is relevant either the institution or the group in some point. The person might be also interested to be credited, is there a copy right on test data? 

If personal data is stored it should be only available to a specific group. Maybe ORC-IDs instead of personal information. 

The question cannot be solved for personal information within the group but should be discussed within the community. A proposal would be to link publicly available data, datasets that have been part of publication and the authors are known publicly otherwise only use pseudonym identifiers. 

Question CQ5.1 was formed to cover personal and credit alternatives of this scenario. 

Information about the machine is useful and required 

#### CQ5.1 - Who [which group or institution] performed a given set of Tensile tests with results in a range between [a] and [b]? 

**Vote**: [Not rated]

**Necessity**: [Required, Desired, Rejected] 

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 

Access control / anonymization must be applied if personal data is involved 



### CQ6 - How much time has passed since the last calibration of the tensile test machine which produced the given results?  

**Vote**: [Not rated]

**Necessity**: Desired, exceptionally low  

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. A calibrated machine degrades over time and produces less accurate or shifted results. 

**Remarks**:  

Question will not be used in that way, alternative CQ6.1 and CQ6.2 contain concrete useful details. The domain experts remark, that nobody would ask for the time passed but rather is the machine calibrated or calibrated according to a given norm. The described scenario is not supposed to happen as something like this should have been caught by the quality assurance of the institute performing the test. 

Related to ISO 9002   


#### CQ6.1 Which software version was used for a given simulation?  

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. Results can have been recorded with different software version and those versions can might have alternating installation, units, or file formats etc. It is required to record the tools and their version and configuration. 

**Remarks**: 

 

#### CQ6.2 Had the machine which produced the given result [x] a valid calibration? 

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. There might be not data available to evaluate the calibration of the machine. And those results should be marked to be used with caution. Same goes to results that are generated from raw data. 

**Remarks**: 


#### CQ6.3 How trustworthy are the results in terms of quality management?  

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. Are the results performed by an institute with a known quality assurance, or are those results already evaluated by another researchers? 

**Remarks**: 


#### CQ6.4 What is the quality of data?

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. Is the meta data fully available? 

**Remarks**: 


#### CQ6.5 Quality assurance of the institute?

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified]  

**Description**:  

The given question tries to cover the following scenario. Is the institute committed to a known quality norm? ISO 9002? 

**Remarks**: 



### CQ7 - Return all Tensile test with duration in seconds and the gauge length in mm. 

**Vote**: [Not rated]

**Necessity**: Rejected 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. Is there a need to store tabular data, like time series within the ontology? CQ7.1 and CQ7.2 represent better options. 

**Remarks**: 

We need time series, but question is not useful. 


#### CQ7.1 Compare displacement time curves and related gauge length 

**Vote**: [Not rated]

**Necessity**: [Required, Desired, Rejected] 

**Belonging**: [Not specified] 

**Description**: 

**Remarks**: 

This question can be used to calculate the velocity-time-curve and compare its stability. 

 

#### CQ7.2 Sampling frequency of tensile test? 

**Vote**: [Not rated]

**Necessity**: [Required, Desired, Rejected]

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. A curve with a certain precision which is given by the sampling frequency.  

**Remarks**: 

Sampling frequencies are not well defined. The Sampling frequencies can be given by time but also by strain. 



### CQ8 - Find all non-Trip steels that behave like one material with respect to specific performance parameters (e.g. minimum strength and hardening value)? 

**Vote**: [Not rated]

**Necessity**: Rejected 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario.  

**Remarks**: 

Trip and Twip steels have a given set of properties and so a steel sold is classified as being trippy or twippy, but in the end a steel is sold by a given set of properties and its strength and behavior under stress. 

#### CQ8.1 Get me the supplement for [material_x] which behaves like [material_y] under the given test. 

Vote: [Not rated]

Necessity: Rejected 

Belonging: [Not specified] 

Description: 

The given question tries to cover the following scenario. The search for a supplement material is essential, either the original material got too expensive or cannot be shaped as desired. A supplement material with the same or almost the same properties is required. 

Remarks: 

 

#### CQ8.2 Find all steels with the given performance parameters 

**Vote**: [Not rated]

**Necessity**: Rejected 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. Same as CQ8.1. 

**Remarks**: 



### CQ9 - Show the stress-strain-curve for a specific test. 

**Vote**: [Not rated]

**Necessity**: Desired 

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. Should images be stored inside the ontology, either via links or blob. 

**Remarks**: 

Raw data is desired and sometime raw data is an image (blob). But if the tabular data is available storing an image is not required



### CQ10 - Find all stress-strain-curves which have a slope of [y] past the point [x] 

**Vote**: [Not rated]

**Necessity**: Rejected  

**Belonging**: [Not specified] 

**Description**: 

The given question tries to cover the following scenario. Should the ontology be able to compute specific characteristics, or should the input support mathematical operations and all results should be stored within the ontology.

**Remarks**: 

Ontology not expected to perform math transformation for questions like these. 

Math. transformations needed: less greater than, greater than, sums (low level math operations) (deriv. higher level math). not clear where boundaries should be. 


#### CQ10.1 Can some quantities be combined to compute another quantity? 

**Vote**: [Not rated]

**Necessity**: Desired  

**Belonging**: [Not specified] 

**Description**:

The given question tries to cover the following scenario. The focus is on units. Are there units that can be combined to new properties? How can the reasoner be of any help.

e.g., different transformations of “energy per Volume” 

**Remarks**: 



### CQ11 - How is the {formability OR crash performance} of material [x] after different types of cold rolling? 

**Vote**: [Not rated]

**Necessity**: [Rejected] 

**Belonging**: Process chain 

**Description**: 

The given question tries to cover the following scenario. While the process has multiple steps is it required to store and query the intermediate results between those process steps, or is only the initial input and final output of interest. 

**Remarks**:

from Verbund-Skizze, chapter 0: "Auf Basis der Ontologie-basierten digitalen Zwillinge von Material, Prozess und Bauteil wird beispielsweise der Einfluss der chemischen Zusammensetzung auf die Eigenschaften des Kaltbands und der Einfluss des Kaltwalzens auf die Umformbarkeit bzw. die Crashperformance des Bauteils dargestellt" 

Nobody is interested in the materials performance before cold rolling since the material is cold rolled anyway. While this is a valid question regarding the process chain and its internal steps, the example of cold rolling of no one's interest. 

#### CQ11.1 - Which measures would you need during the process chain to be measured to get feedback on the process itself. 

**Vote**: [Not rated]

**Necessity**: [Desired, Rejected] 

**Belonging**: Process chain 

**Description**: 

The given question tries to cover the following scenario. Asks about the change of material properties after a given process. 

**Remarks**: 

#### CQ11.2 - How is the {formability OR crash performance} of material [x] after different types of [steps in the process chain]? 

**Vote**: [Not rated]

**Necessity**: [Desired, Rejected] 

**Belonging**: Process chain 

**Description**: 

The given question tries to cover the following scenario. Asks about the change of material properties after a given process. 

**Remarks**: 

### CQ12 - On which numerical conditions is the material crash card based on.
Necessity: [Required, Desired, Rejected]

Belonging: [Generic, Steel Specific, Material Science Specific, Tensile Test, Microstructure-property relations, Workflows, Input/Output parameters, Simulations]

Description: On which numerical conditions is the material crash card based on (Element typ, Element size, implicit/explicit, numerical solver, ...)

Remarks

### CQ13 - On which experiments (stress strain curves, key values etc.) is the material crash card based on.
Necessity: [Required, Desired, Rejected]

Belonging: [Generic, Steel Specific, Material Science Specific, Tensile Test, Microstructure-property relations, Workflows, Input/Output parameters, Simulations]

Description: give all available informations about the referenced tests (tensile test, shear test, nakajima test, ....)

Remarks

### CQ14 - With which experiments is the material crash card validated.
Necessity: [Required, Desired, Rejected]

Belonging: [Generic, Steel Specific, Material Science Specific, Tensile Test, Microstructure-property relations, Workflows, Input/Output parameters, Simulations]

Description: all informations about the belonging validation tests: specimen or component, quasistatic or dynamic loading etc. ?

Remarks

### CQ14 - For which solver is the material card usable.
Necessity: [Required, Desired, Rejected]

Belonging: [Generic, Steel Specific, Material Science Specific, Tensile Test, Microstructure-property relations, Workflows, Input/Output parameters, Simulations]

Description:

Remarks

	 
